@@ -12,10 +12,11 @@
 #ifndef CITUS_DEPENDED_OBJECT_H
 #define CITUS_DEPENDED_OBJECT_H
 
-#include "distributed/commands.h"
 #include "nodes/nodes.h"
 #include "nodes/parsenodes.h"
 
+#include "distributed/commands.h"
+
 extern bool HideCitusDependentObjects;
 
 /* DistOpsValidationState to be used to determine validity of dist ops */
@@ -24,7 +25,8 @@ typedef enum DistOpsValidationState
 	HasAtLeastOneValidObject,
 	HasNoneValidObject,
 	HasObjectWithInvalidOwnership,
-	NoAddressResolutionRequired
+	NoAddressResolutionRequired,
+	ShouldQualifyAfterLocalCreation
 } DistOpsValidationState;
 
 extern void SetLocalClientMinMessagesIfRunningPGTests(int
