@@ -15,11 +15,12 @@
 
 #include "catalog/pg_sequence.h"
 #include "commands/sequence.h"
-#include "distributed/coordinator_protocol.h"
 #include "lib/stringinfo.h"
 #include "nodes/parsenodes.h"
 #include "nodes/pg_list.h"
 
+#include "distributed/coordinator_protocol.h"
+
 /* Function declarations for version independent Citus ruleutils wrapper functions */
 extern char * pg_get_extensiondef_string(Oid tableRelationId);
 extern Oid get_extension_schema(Oid ext_oid);
@@ -28,7 +29,8 @@ extern char * pg_get_serverdef_string(Oid tableRelationId);
 extern char * pg_get_sequencedef_string(Oid sequenceRelid);
 extern Form_pg_sequence pg_get_sequencedef(Oid sequenceRelationId);
 extern char * pg_get_tableschemadef_string(Oid tableRelationId,
-										   IncludeSequenceDefaults includeSequenceDefaults,
+										   IncludeSequenceDefaults
+										   includeSequenceDefaults,
 										   IncludeIdentities includeIdentityDefaults,
 										   char *accessMethod);
 extern void EnsureRelationKindSupported(Oid relationId);
@@ -43,6 +45,7 @@ extern bool contain_nextval_expression_walker(Node *node, void *context);
 extern char * pg_get_replica_identity_command(Oid tableRelationId);
 extern List * pg_get_row_level_security_commands(Oid relationId);
 extern const char * RoleSpecString(RoleSpec *spec, bool withQuoteIdentifier);
+extern List * ExpandMergedSubscriptingRefEntries(List *targetEntryList);
 extern char * flatten_reloptions(Oid relid);
 
 /* Function declarations for version dependent PostgreSQL ruleutils functions */
@@ -59,5 +62,6 @@ extern char * generate_operator_name(Oid operid, Oid arg1, Oid arg2);
 extern List * getOwnedSequences_internal(Oid relid, AttrNumber attnum, char deptype);
 extern void AppendOptionListToString(StringInfo stringData, List *options);
 
+extern void ensure_update_targetlist_in_param_order(List *targetList);
 
 #endif /* CITUS_RULEUTILS_H */
