@@ -12,9 +12,10 @@
 #ifndef COLOCATION_UTILS_H_
 #define COLOCATION_UTILS_H_
 
-#include "distributed/shardinterval_utils.h"
 #include "nodes/pg_list.h"
 
+#include "distributed/shardinterval_utils.h"
+
 #define INVALID_COLOCATION_ID 0
 
 extern uint32 TableColocationId(Oid distributedTableId);
@@ -52,13 +53,11 @@ extern List * ColocationGroupTableList(uint32 colocationId, uint32 count);
 extern void DeleteColocationGroup(uint32 colocationId);
 extern void DeleteColocationGroupLocally(uint32 colocationId);
 extern uint32 FindColocateWithColocationId(Oid relationId, char replicationModel,
-										   Oid distributionColumnType,
-										   Oid distributionColumnCollation,
+										   Var *distributionColumn,
 										   int shardCount, bool shardCountIsStrict,
 										   char *colocateWithTableName);
 extern void EnsureTableCanBeColocatedWith(Oid relationId, char replicationModel,
-										  Oid distributionColumnType,
-										  Oid sourceRelationId);
+										  Var *distributionColumn, Oid sourceRelationId);
 extern void AcquireColocationDefaultLock(void);
 extern void ReleaseColocationDefaultLock(void);
 
