@@ -33,6 +33,18 @@
 extern int PlannerLevel;
 
 
+/* RouterPlanType is used to determine the router plan to invoke */
+typedef enum RouterPlanType
+{
+	INSERT_SELECT_INTO_CITUS_TABLE,
+	INSERT_SELECT_INTO_LOCAL_TABLE,
+	DML_QUERY,
+	SELECT_QUERY,
+	MERGE_QUERY,
+	REPLAN_WITH_BOUND_PARAMETERS
+} RouterPlanType;
+
+
 typedef struct RelationRestrictionContext
 {
 	bool allReferenceTables;
@@ -99,8 +111,15 @@ typedef struct FastPathRestrictionContext
 	 * Set to true when distKey = Param; in the queryTree
 	 */
 	bool distributionKeyHasParam;
-}FastPathRestrictionContext;
 
+	/*
+	 * Indicates to hold off calling the fast path planner until its
+	 * known if the shard is local or not.
+	 */
+	bool delayFastPathPlanning;
+} FastPathRestrictionContext;
+
+struct DistributedPlanningContext;
 typedef struct PlannerRestrictionContext
 {
 	RelationRestrictionContext *relationRestrictionContext;
@@ -114,6 +133,18 @@ typedef struct PlannerRestrictionContext
 	 */
 	FastPathRestrictionContext *fastPathRestrictionContext;
 	MemoryContext memoryContext;
+
+#if PG_VERSION_NUM >= PG_VERSION_18
+
+	/*
+	 * Enable access to the distributed planning context from
+	 * planner hooks called by Postgres. Enables Citus to track
+	 * changes made by Postgres to the query tree (such as
+	 * expansion of virtual columns) and ensure they are reflected
+	 * back to subsequent distributed planning.
+	 */
+	struct DistributedPlanningContext *planContext;
+#endif
 } PlannerRestrictionContext;
 
 typedef struct RelationShard
@@ -220,7 +251,7 @@ extern PlannedStmt * distributed_planner(Query *parse,
  * in distributed queries
  */
 #define LOCAL_TABLE_SUBQUERY_CTE_HINT \
-	"Use CTE's or subqueries to select from local tables and use them in joins"
+		"Use CTE's or subqueries to select from local tables and use them in joins"
 
 extern List * ExtractRangeTableEntryList(Query *query);
 extern bool NeedsDistributedPlanning(Query *query);
