@@ -20,8 +20,8 @@
 /* Adaptive executor repartitioning related defines */
 #define WORKER_CREATE_SCHEMA_QUERY "SELECT worker_create_schema (" UINT64_FORMAT ", %s);"
 #define WORKER_REPARTITION_CLEANUP_QUERY "SELECT worker_repartition_cleanup (" \
-	UINT64_FORMAT \
-	");"
+		UINT64_FORMAT \
+		");"
 
 
 /* Enumeration that represents distributed executor types */
@@ -29,7 +29,8 @@ typedef enum
 {
 	MULTI_EXECUTOR_INVALID_FIRST = 0,
 	MULTI_EXECUTOR_ADAPTIVE = 1,
-	MULTI_EXECUTOR_NON_PUSHABLE_INSERT_SELECT = 2
+	MULTI_EXECUTOR_NON_PUSHABLE_INSERT_SELECT = 2,
+	MULTI_EXECUTOR_NON_PUSHABLE_MERGE_QUERY = 3
 } MultiExecutorType;
 
 
