@@ -21,7 +21,8 @@ extern MultiConnection * StartPlacementConnection(uint32 flags,
 												  struct ShardPlacement *placement,
 												  const char *userName);
 extern MultiConnection *  GetConnectionIfPlacementAccessedInXact(int flags,
-																 List *placementAccessList,
+																 List *
+																 placementAccessList,
 																 const char *userName);
 extern MultiConnection * StartPlacementListConnection(uint32 flags,
 													  List *placementAccessList,
@@ -32,8 +33,7 @@ extern void AssignPlacementListToConnection(List *placementAccessList,
 											MultiConnection *connection);
 
 extern void ResetPlacementConnectionManagement(void);
-extern void MarkFailedShardPlacements(void);
-extern void PostCommitMarkFailedShardPlacements(bool using2PC);
+extern void ErrorIfPostCommitFailedShardPlacements(void);
 
 extern void CloseShardPlacementAssociation(struct MultiConnection *connection);
 extern void ResetShardPlacementAssociation(struct MultiConnection *connection);
