@@ -26,7 +26,8 @@ extern int ValuesMaterializationThreshold;
 
 extern bool CanPushdownSubquery(Query *subqueryTree, bool outerMostQueryHasLimit);
 extern bool ShouldUseSubqueryPushDown(Query *originalQuery, Query *rewrittenQuery,
-									  PlannerRestrictionContext *plannerRestrictionContext);
+									  PlannerRestrictionContext *
+									  plannerRestrictionContext);
 extern bool JoinTreeContainsSubquery(Query *query);
 extern bool IsNodeSubquery(Node *node);
 extern bool HasEmptyJoinTree(Query *query);
@@ -41,12 +42,14 @@ extern DeferredErrorMessage * DeferErrorIfUnsupportedSubqueryPushdown(Query *
 																	  originalQuery,
 																	  PlannerRestrictionContext
 																	  *
-																	  plannerRestrictionContext);
+																	  plannerRestrictionContext,
+																	  bool plannerPhase);
 extern DeferredErrorMessage * DeferErrorIfCannotPushdownSubquery(Query *subqueryTree,
 																 bool
 																 outerMostQueryHasLimit);
 extern DeferredErrorMessage * DeferErrorIfUnsupportedUnionQuery(Query *queryTree);
 extern bool IsJsonTableRTE(RangeTblEntry *rte);
-
+extern bool IsOuterJoinExpr(Node *node);
+extern void FlattenGroupExprs(Query *query);
 
 #endif /* QUERY_PUSHDOWN_PLANNING_H */
