@@ -30,11 +30,22 @@ typedef enum TargetWorkerSet
 	 */
 	NON_COORDINATOR_METADATA_NODES,
 
+	/*
+	 * All the active primary nodes in the metadata which have metadata
+	 * except the local node
+	 */
+	REMOTE_METADATA_NODES,
+
 	/*
 	 * All the active primary nodes in the metadata except the coordinator
 	 */
 	NON_COORDINATOR_NODES,
 
+	/*
+	 * All the active primary nodes in the metadata except the local node
+	 */
+	REMOTE_NODES,
+
 	/*
 	 * All active primary nodes in the metadata
 	 */
@@ -57,6 +68,10 @@ extern void SendCommandToWorkersAsUser(TargetWorkerSet targetWorkerSet,
 									   const char *nodeUser, const char *command);
 extern void SendCommandToWorkerAsUser(const char *nodeName, int32 nodePort,
 									  const char *nodeUser, const char *command);
+extern void SendCommandToRemoteMetadataNodesParams(const char *command,
+												   const char *user, int parameterCount,
+												   const Oid *parameterTypes,
+												   const char *const *parameterValues);
 extern bool SendOptionalCommandListToWorkerOutsideTransaction(const char *nodeName,
 															  int32 nodePort,
 															  const char *nodeUser,
@@ -66,8 +81,10 @@ extern bool SendOptionalCommandListToWorkerOutsideTransactionWithConnection(
 	List *
 	commandList);
 extern bool SendOptionalMetadataCommandListToWorkerInCoordinatedTransaction(const
-																			char *nodeName,
-																			int32 nodePort,
+																			char *
+																			nodeName,
+																			int32
+																			nodePort,
 																			const char *
 																			nodeUser,
 																			List *
@@ -75,22 +92,27 @@ extern bool SendOptionalMetadataCommandListToWorkerInCoordinatedTransaction(cons
 extern void SendCommandToWorkersWithMetadata(const char *command);
 extern void SendCommandToWorkersWithMetadataViaSuperUser(const char *command);
 extern void SendCommandListToWorkersWithMetadata(List *commands);
+extern void SendCommandToRemoteNodesWithMetadata(const char *command);
+extern void SendCommandToRemoteNodesWithMetadataViaSuperUser(const char *command);
+extern void SendCommandListToRemoteNodesWithMetadata(List *commands);
+extern void SendBareCommandListToRemoteMetadataNodes(List *commandList);
 extern void SendBareCommandListToMetadataWorkers(List *commandList);
 extern void EnsureNoModificationsHaveBeenDone(void);
 extern void SendCommandListToWorkerOutsideTransaction(const char *nodeName,
 													  int32 nodePort,
 													  const char *nodeUser,
 													  List *commandList);
-extern void SendCommandListToWorkerOutsideTransactionWithConnection(
-	MultiConnection *workerConnection,
-	List *commandList);
+extern void SendCommandListToWorkerOutsideTransactionWithConnection(MultiConnection *
+																	workerConnection,
+																	List *commandList);
 extern void SendCommandListToWorkerListWithBareConnections(List *workerConnections,
 														   List *commandList);
-extern void SendMetadataCommandListToWorkerListInCoordinatedTransaction(
-	List *workerNodeList,
-	const char *
-	nodeUser,
-	List *commandList);
+extern void SendMetadataCommandListToWorkerListInCoordinatedTransaction(List *
+																		workerNodeList,
+																		const char *
+																		nodeUser,
+																		List *
+																		commandList);
 extern void RemoveWorkerTransaction(const char *nodeName, int32 nodePort);
 
 /* helper functions for worker transactions */
